@@ -26,6 +26,7 @@ from ._read_common import (
     SYNC_SIZE,
     HEADER_SCHEMA,
     missing_codec_lib,
+    NAMED_TYPES,
 )
 from .const import (
     MCS_PER_HOUR,
@@ -60,6 +61,7 @@ AVRO_TYPES = {
 
 decimal_context = Context()
 epoch = datetime(1970, 1, 1, tzinfo=timezone.utc)
+epoch_naive = datetime(1970, 1, 1)
 
 
 def match_types(writer_type, reader_type):
@@ -117,6 +119,15 @@ def match_schemas(w_schema, r_schema):
         elif w_type == r_type == "array":
             if match_types(w_schema["items"], r_schema["items"]):
                 return r_schema
+        elif w_type in NAMED_TYPES and r_type in NAMED_TYPES:
+            if w_type == r_type == "fixed" and w_schema["size"] != r_schema["size"]:
+                raise SchemaResolutionError(
+                    f"Schema mismatch: {w_schema} size is different than {r_schema} size"
+                )
+            if w_schema["name"] == r_schema["name"] or w_schema["name"] in r_schema.get(
+                "aliases", []
+            ):
+                return r_schema
         elif match_types(w_type, r_type):
             return r_schema
         raise SchemaResolutionError(error_msg)
@@ -155,11 +166,25 @@ def read_timestamp_millis(data, writer_schema=None, reader_schema=None):
     return epoch + timedelta(microseconds=data * 1000)
 
 
+def read_local_timestamp_millis(
+    data: int, writer_schema=None, reader_schema=None
+) -> datetime:
+    # Cannot use datetime.fromtimestamp: https://bugs.python.org/issue36439
+    return epoch_naive + timedelta(microseconds=data * 1000)
+
+
 def read_timestamp_micros(data, writer_schema=None, reader_schema=None):
     # Cannot use datetime.fromtimestamp: https://bugs.python.org/issue36439
     return epoch + timedelta(microseconds=data)
 
 
+def read_local_timestamp_micros(
+    data: int, writer_schema=None, reader_schema=None
+) -> datetime:
+    # Cannot use datetime.fromtimestamp: https://bugs.python.org/issue36439
+    return epoch_naive + timedelta(microseconds=data)
+
+
 def read_date(data, writer_schema=None, reader_schema=None):
     return date.fromordinal(data + DAYS_SHIFT)
 
@@ -561,7 +586,9 @@ def skip_record(decoder, writer_schema, named_schemas):
 
 LOGICAL_READERS = {
     "long-timestamp-millis": read_timestamp_millis,
+    "long-local-timestamp-millis": read_local_timestamp_millis,
     "long-timestamp-micros": read_timestamp_micros,
+    "long-local-timestamp-micros": read_local_timestamp_micros,
     "int-date": read_date,
     "bytes-decimal": read_decimal,
     "fixed-decimal": read_decimal,
@@ -1143,7 +1170,7 @@ def schemaless_reader(fo, writer_schema, reader_schema=None, return_record_name=
     Example::
 
         parsed_schema = fastavro.parse_schema(schema)
-        with open('file.avro', 'rb') as fp:
+        with open('file', 'rb') as fp:
             record = fastavro.schemaless_reader(fp, parsed_schema)
 
     Note: The ``schemaless_reader`` can only read a single record.
@@ -1170,7 +1197,12 @@ def schemaless_reader(fo, writer_schema, reader_schema=None, return_record_name=
 
 
 def is_avro(path_or_buffer):
-    """Return True if path (or buffer) points to an Avro file.
+    """Return True if path (or buffer) points to an Avro file. This will only
+    work for avro files that contain the normal avro schema header like those
+    create from :func:`~fastavro._write_py.writer`. This function is not intended
+    to be used with binary data created from
+    :func:`~fastavro._write_py.schemaless_writer` since that does not include the
+    avro header.
 
     Parameters
     ----------
